import java.io.*;
import java.net.*;
/**
 * Security manager to allow only one ip to connect to a specific port.
 * 
 * Copyright (C) 2008 Jesper Jeeninga
 *
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * @author Jesper Jeeninga
 *
 */
public class SampSecurityManager extends SecurityManager {

	private String _host;
	private int _port;
	
	public SampSecurityManager(String host, int port) {
		super();
		try {
			_host = InetAddress.getByName(host).getHostAddress();
			_port = port;
		}
		catch (UnknownHostException e) {
			_host = host;
		}
	}

	public void checkAccept(String host, int port) {
		try {
			host = InetAddress.getByName(host).getHostAddress();
		}
		catch (UnknownHostException e) {
		}
		if(!host.equals(_host)) throw new SecurityException ("Connecting not allowed for " + host);
	}

	public void checkListen(int port) {
		if (port != _port) {
			throw new SecurityException ("Listening not allowed on port " + port);
		}
	}
	
	public void	checkRead(FileDescriptor fd) {
		//allowed	 
	}
	
	public void	checkRead(String file) {
		//allowed		
	}	
	public void	checkWrite(FileDescriptor fd) {
		//allowed	 
	}
	
	public void	checkWrite(String file) {
		//allowed		
	}

}
